import logging
import os.path
from pickuppath import pickup_path


def main():
    import argparse
    parser = argparse.ArgumentParser()
    parser.add_argument("filename")
    parser.add_argument("-c", "--current", default=None)
    parser.add_argument("--default", default=None)
    parser.add_argument("--debug", action="store_true")
    args = parser.parse_args()
    default = args.default or os.path.join("~", args.filename)
    if args.debug:
        logging.basicConfig(level=logging.DEBUG)
    print(pickup_path(args.filename, current=args.current, default=default))


if __name__ == "__main__":
    main()



# -*- coding:utf-8 -*-
import logging
import os.path
logger = logging.getLogger(__name__)


def pickup_path(filename, current=None, default=None):
    """pickupping the config file path

    start path = "/foo/bar/boo", filename = "config.ini"
    finding candidates are ["/foo/bar/boo/config.ini", "/foo/bar/config.ini", "/foo/config.ini", "/config.ini"]
    """
    current = current or os.getcwd()
    start_point = os.path.normpath(os.path.abspath(current))
    current = start_point
    candidates = []
    while True:
        candidates.append(os.path.join(current, filename))
        if current == "/":
            break
        current, dropped = os.path.split(current)

    for path in candidates:
        logger.debug("check: %s", path)
        if os.path.exists(path):
            return path
    return default
